Learn R Programming

SocialPosition (version 1.0.1)

convert_from_PCS1982_4l_to_PCS2003_4l: The conversion of the French PCS 1982 into the French PCS 2003

Description

This function converts occupational codes of the French Professions et Categories Socioprofessionnelles from the 1982 codes into the 2003 codes

Usage

convert_from_PCS1982_4l_to_PCS2003_4l(PCS1982_4l, data)

Arguments

PCS1982_4l
The name of the variable containing

data
The name of the dataset

References

Documentation on the French Professions et Categories Socioprofessionnelles (PCS) 1982 and 2003 can be found on the French National Statistic Agency, the INSEE (only in French):

Examples

Run this code
#load the data
data(data_PCS1982)

#visualize the data
str(data_PCS1982)
head(data_PCS1982)

#check the variable PCS1982 needed for the conversion
table(data_PCS1982$PCS1982)

#Then, you can run the function:
data_PCS1982 <- convert_from_PCS1982_4l_to_PCS2003_4l(
				PCS1982_4l=data_PCS1982$PCS1982,
				data=data_PCS1982)

#Check the variables created:
names(data_PCS1982)
table(data_PCS1982$PCS2003_4l) # CSP 2003 4 digits (4 niveaux)
table(data_PCS1982$PCS2003_3l) # CSP 2003 3 digits (3 niveaux)
table(data_PCS1982$PCS2003_2l) # CSP 2003 2 digits (2 niveaux)
table(data_PCS1982$PCS2003_1l) # CSP 2003 1 digit (1 niveau)

Run the code above in your browser using DataLab