Learn R Programming

SocialPosition (version 1.0.1)

convert_from_PCS2003_4l_to_ISCO88_3d: The conversion of the French PCS 2003 into the ISCO 1988 codes

Description

This function converts occupational codes of the French Professions et Categories Socioprofessionnelles 2003 into the occupational codes of the ISCO 1988 classification on 3 digits

Usage

convert_from_PCS2003_4l_to_ISCO88_3d(PCS2003_4l, data)

Arguments

PCS2003_4l
The name of the variable containing the French PCS 2003 coded on 4 levels (i.e. 3 digits followed by 1 letter, such as 226a)
data
The name of the dataset

References

Documentation on the French Professions et Categories Socioprofessionnelles (PCS) 2003 and on the ISCO 1988 can be found:

Examples

Run this code
#load the data
data(data_PCS2003_4l)

#visualize the data
str(data_PCS2003_4l)
head(data_PCS2003_4l)

#check the variable needed for the conversion
table(data_PCS2003_4l$codes_4_level)

#Then, you can run the function:
data_PCS2003_4l <- convert_from_PCS2003_4l_to_ISCO88_3d(
				   PCS2003_4l=data_PCS2003_4l$codes_4_level, 
				   data=data_PCS2003_4l)

#Check the variable created:
names(data_PCS2003_4l)
table(data_PCS2003_4l$ISCO88_3d)

Run the code above in your browser using DataLab